@@ -13,10 +13,10 @@
 
 #include "networkmodel.h"
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMNicFactory, "kcm_nic.json", registerPlugin<KCMNic>();)
+K_PLUGIN_CLASS_WITH_JSON(KCMNic, "kcm_nic.json")
 
-KCMNic::KCMNic(QObject *parent, const QVariantList &list)
-    : KQuickAddons::ConfigModule(parent, list)
+KCMNic::KCMNic(QObject *parent, const KPluginMetaData &data, const QVariantList &list)
+    : KQuickAddons::ConfigModule(parent, data, list)
 {
     KAboutData *about = new KAboutData(i18n("kcm_nic"),
                                        i18nc("@title:window", "Network Interfaces"),
